@@ -1,4 +1,5 @@
 """pytest-bdd Exceptions."""
+import six
 
 
 class StepError(Exception):
@@ -21,9 +22,19 @@ class ScenarioNotFound(ScenarioValidationError):
     """Scenario Not Found."""
 
 
+class ExamplesNotValidError(ScenarioValidationError):
+
+    """Example table is not valid."""
+
+
 class ScenarioExamplesNotValidError(ScenarioValidationError):
 
-    """Scenario steps argumets do not match declared scenario examples."""
+    """Scenario steps parameters do not match declared scenario examples."""
+
+
+class FeatureExamplesNotValidError(ScenarioValidationError):
+
+    """Feature example table is not valid."""
 
 
 class StepTypeError(ScenarioValidationError):
@@ -44,3 +55,20 @@ class StepDefinitionNotFoundError(Exception):
 class InvalidStepParserError(Exception):
 
     """Invalid step parser."""
+
+
+class NoScenariosFound(Exception):
+
+    """No scenarios found."""
+
+
+@six.python_2_unicode_compatible
+class FeatureError(Exception):
+
+    """Feature parse error."""
+
+    message = u"{0}.\nLine number: {1}.\nLine: {2}.\nFile: {3}"
+
+    def __str__(self):
+        """String representation."""
+        return self.message.format(*self.args)
