@@ -1,22 +1,17 @@
 """Step parsers."""
 
 from __future__ import absolute_import
+
 import re as base_re
-import warnings
 
 import parse as base_parse
-from parse_type import cfparse as base_cfparse
-
 import six
+from parse_type import cfparse as base_cfparse
 
 from .exceptions import InvalidStepParserError
 
 
-RE_TYPE = type(base_re.compile(''))
-
-
 class StepParser(object):
-
     """Parser of the individual step."""
 
     def __init__(self, name):
@@ -35,7 +30,6 @@ class StepParser(object):
 
 
 class re(StepParser):
-
     """Regex step parser."""
 
     def __init__(self, name, *args, **kwargs):
@@ -56,7 +50,6 @@ class re(StepParser):
 
 
 class parse(StepParser):
-
     """parse step parser."""
 
     def __init__(self, name, *args, **kwargs):
@@ -80,7 +73,6 @@ class parse(StepParser):
 
 
 class cfparse(parse):
-
     """cfparse step parser."""
 
     def __init__(self, name, *args, **kwargs):
@@ -90,7 +82,6 @@ class cfparse(parse):
 
 
 class string(StepParser):
-
     """Exact string step parser."""
 
     def parse_arguments(self, name):
@@ -113,16 +104,9 @@ def get_parser(step_name):
     :return: step parser object
     :rtype: StepArgumentParser
     """
-    if isinstance(step_name, RE_TYPE):
-        # backwards compartibility
-        warn = (
-            'pytest-bdd [{0}]: Direct usage of regex is deprecated. Please use pytest_bdd.parsers.re instead.'.format(
-                step_name.pattern)
-        )
-        warnings.warn(warn)
-        print(warn)
-        return re(step_name.pattern, flags=step_name.flags)
-    elif isinstance(step_name, six.string_types):
+    if isinstance(step_name, six.string_types):
+        if isinstance(step_name, six.binary_type):  # Python 2 compatibility
+            step_name = step_name.decode('utf-8')
         return string(step_name)
     elif not hasattr(step_name, 'is_matching') or not hasattr(step_name, 'parse_arguments'):
         raise InvalidStepParserError(step_name)
