@@ -6,6 +6,9 @@ that enriches the pytest test reporting.
 
 import time
 
+from .feature import force_unicode
+from .utils import get_parametrize_markers_args
+
 
 class StepReport(object):
 
@@ -60,7 +63,7 @@ class StepReport(object):
 
 class ScenarioReport(object):
 
-    """Scenario excecution report."""
+    """Scenario execution report."""
 
     def __init__(self, scenario, node):
         """Scenario report constructor.
@@ -71,16 +74,20 @@ class ScenarioReport(object):
         self.scenario = scenario
         self.step_reports = []
         self.param_index = None
-        parametrize = node.keywords._markers.get('parametrize')
-        if parametrize and scenario.examples:
-            param_names = parametrize.args[0] if isinstance(parametrize.args[0], (tuple, list)) else [
-                parametrize.args[0]]
-            param_values = parametrize.args[1]
+        parametrize_args = get_parametrize_markers_args(node)
+        if parametrize_args and scenario.examples:
+            param_names = parametrize_args[0] if isinstance(parametrize_args[0], (tuple, list)) else [
+                parametrize_args[0]]
+            param_values = parametrize_args[1]
             node_param_values = [node.funcargs[param_name] for param_name in param_names]
             if node_param_values in param_values:
                 self.param_index = param_values.index(node_param_values)
             elif tuple(node_param_values) in param_values:
                 self.param_index = param_values.index(tuple(node_param_values))
+        self.example_kwargs = {
+            example_param: force_unicode(node.funcargs[example_param])
+            for example_param in scenario.get_example_params()
+        }
 
     @property
     def current_step_report(self):
@@ -129,7 +136,8 @@ class ScenarioReport(object):
                     "rows": params,
                     "row_index": self.param_index,
                 }
-            ] if scenario.examples else []
+            ] if scenario.examples else [],
+            "example_kwargs": self.example_kwargs,
         }
 
     def fail(self):
