@@ -3,7 +3,6 @@
 Check the parent givens are collected and overriden in the local conftest.
 """
 from pytest_bdd.steps import get_step_fixture_name, WHEN
-from pytest_bdd.utils import get_fixture_value
 
 
 def test_parent(parent, overridable):
@@ -17,4 +16,4 @@ def test_parent(parent, overridable):
 
 def test_global_when_step(request):
     """Test when step defined in the parent conftest."""
-    get_fixture_value(request, get_step_fixture_name('I use a when step from the parent conftest', WHEN))
+    request.getfixturevalue(get_step_fixture_name('I use a when step from the parent conftest', WHEN))
